/*
 * K2G: Clock data
 *
 * (C) Copyright 2015
 *     Texas Instruments Incorporated, <www.ti.com>
 *
 * SPDX-License-Identifier:     GPL-2.0+
 */

#ifndef __ASM_ARCH_CLOCK_K2G_H
#define __ASM_ARCH_CLOCK_K2G_H

#define PLLSET_CMD_LIST		"<pa|arm|ddr3>"

#define DEV_SUPPORTED_SPEEDS	0xff
#define ARM_SUPPORTED_SPEEDS	0x3ff

#define KS2_CLK1_6 sys_clk0_6_clk

#endif
